@@ -1,10 +1,10 @@
 package Number::MuPhone;
-use 5.012;
+use strictures 2;
 use Number::MuPhone::Parser;
 use Number::MuPhone::Data;
 use Number::MuPhone::Config;
 
-our $VERSION = '0.07_003';
+our $VERSION = '0.01';
 
 # need this non-Moo encapsulation to allow backwards compatability with Number::Phone
 
@@ -12,49 +12,38 @@ our $VERSION = '0.07_003';
 # (useful when amending parsers, to keep an eye out for issues)
 # Only really used when checking tweaks to the Parser modules
 # bad syntax silently dies otherwise and it can be confusing while developing
-our $DEBUG=1;
+our $DEBUG=0;
 
 
 sub new {
   my ($class,@args) = @_;
 
-  my ($country_or_countries,$number,$is_number_phone)=('','',0);
+  my ($country,$number,$is_number_phone)=('','',0);
   # normal instantiation
   if ( ref $args[0] eq 'HASH' ) {
-    $country_or_countries = $args[0]->{country};
-    $number               = $args[0]->{number};
+    $country = $args[0]->{country};
+    $number  = $args[0]->{number};
   }
   # Number::Phone style
   else {
     $number  = pop @args;
-    $country_or_countries = pop @args;
+    $country = pop @args;
     $is_number_phone=1;
   }
   $number||='';
 
   # only number supplied - let's look up the country or use default (if set)
-  if (!$country_or_countries) {
-    $country_or_countries = _phone2country($number);
+  if (!$country) {
+    $country = _phone2country($number)
+               || $Number::MuPhone::Config::config->{default_country}
+               || '';
   }
 
-  $country_or_countries = defined $country_or_countries
-                          ? $country_or_countries
-                          : [ $Number::MuPhone::Config::config->{default_country} ];
-
-  # country_or_countries can be an array of possible countries or a string
-  # if string, coerce to array
-  unless (ref $country_or_countries eq 'ARRAY') {
-    $country_or_countries = [ uc($country_or_countries) ];
-  }
+  $country = uc($country);
 
   # at this point we have enough valid data to instantiate a parser
-  # by iterating through possible countries
   my $parser_obj;
-  COUNTRY: foreach my $country (@$country_or_countries) {
-    unless ($country =~ /^[A-Z]{2}$/) {
-      warn "Invalid country: $country";
-      next COUNTRY;
-    }
+  if ($country) {
     my $parser_module = "Number::MuPhone::Parser::$country";
     eval {
       eval "use $parser_module";
@@ -70,7 +59,6 @@ sub new {
       });
       $parser_obj->error("Invalid country ($country)");
     }
-    last COUNTRY unless $parser_obj->error;
   }
 
   # if load fails, default back to base class and set an error
@@ -81,19 +69,6 @@ sub new {
     });
   }
 
-  # Improve error message for some strings
-  # starts with a + but not a valid international country?
-  if ( $parser_obj->error && $number =~ /^\s*\+(.)/ ) {
-    my $first_digit = $1;
-    if ( $first_digit eq '0' ) {
-      $parser_obj ->error('Invalid country code - no country code begins with a zero');
-    }
-    else {
-      $parser_obj ->error('Invalid country code - could not determine country');
-    }
-  }
-
-
   # duplicate Number::Phone behavior
   if ( $number && $parser_obj->error && $is_number_phone ) {
     $DEBUG && warn "ERROR: ".$parser_obj->error;
@@ -108,7 +83,7 @@ sub _phone2country {
 
   # if number doesn't begins with + we can't determine the country
   # if you need a default country, set 'default_country' in a config file, set it in a config file
-  $num =~ /^\s*\+/ or return undef;
+  $num =~ /^\s*\+/ or return '';
 
   # strip out non-digits
   $num =~ s/[^0-9]//g;
@@ -116,21 +91,21 @@ sub _phone2country {
   # deal with NANP insanity
   if( $num =~ m/^1(\d{3})\d{7}/ ) {
     my $area = $1;
-    if (my $country = $Number::MuPhone::Data::nanp->{$area}) {
+    if (my $country = $Number::MuPhone::Data::NANP_areas{$area}) {
       return $country;
     }
     else {
-      return undef;
+      return 'NANP';
     }
   } else {
     my @prefixes = map { substr($num, 0, $_) } reverse 1..7;
     foreach my $idd (@prefixes) {
-      if( my $country_arrayref = $Number::MuPhone::Data::idd_codes->{$idd} ) {
-        return $country_arrayref;
+      if( my $country = $Number::MuPhone::Data::idd_codes{$idd} ) {
+        return $country;
       }
     }
   }
-  return undef;
+  return '';
 }
 
 1;
@@ -145,10 +120,13 @@ __END__
 
 Number::MuPhone - phone number parsing and display
 
+=head1 VERSION
+
+version 0,01
+
 =head1 SYNOPSIS
 
-  use strict;
-  use warnings;
+  use strictures 2;
   use Number::MuPhone;
 
   my $num_us = Number::MuPhone->new({number => '+12035031111'});
@@ -179,7 +157,7 @@ One sentence summary:
 "Parse and display phone numbers from/to multiple formats"
 
 This module came about when I was trying to write a parser to run a batch
-job for several million numbers. Number::Phone looked like it fit the bill, but
+job for 33 million numbers. Number::Phone looked like it fit the bill, but
 it contains an undocumented cache that caused issues with such large data
 sets. I initially looked at patching Number::Phone, but soon realised that
 would be a lot more work than I anticipated. Couple that in with extra 
@@ -259,9 +237,12 @@ $num->storage_formatted_number
   my $num = Number::MuPhone->new({ number => '203 503 1111 extension 1234', country => 'US' });
   $num->storage_formatted_number -> '+1 2035031111 x1234'  
 
+$num->E123
+  Number in E.123 format for display
+
 $num->international_display
   Display number in standard +COUNTRY_CODE NUMBER format 
-  E123 international format of number
+  Alias of $num->E123
 
 $num->dial_from( $obj || num || '2 char country code');
 $num->display_from( $obj || num || '2 char country code');
@@ -279,13 +260,13 @@ $num->display_from( $obj || num || '2 char country code');
   my $num_us = Number::MuPhone->new('+12035031111');
 
   $num_uk->dial                                 # 02012341234
-  $num_uk->dial_from('GB')                      # 02012341234
+  $num_uk->dial_from('UK')                      # 02012341234
   $num_uk->dial_from('US')                      # 011442012341234
   $num_uk->dial_from('+12035031111')            # 011442012341234
   $num_uk->dial_from($num_us)                   # 011442012341234
   
   $num_uk->display                              # 020 1234 1234
-  $num_uk->display_from('GB')                   # 020 1234 1234
+  $num_uk->display_from('UK')                   # 020 1234 1234
   $num_uk->display_from('US')                   # 011 44 20 1234 1234
   $num_uk->display_from('+12035031111')         # 011 44 20 1234 1234
   $num_uk->display_from($num_us)                # 011 44 20 1234 1234
@@ -299,6 +280,10 @@ $num->international_dial
   Full number to dial, including extension
   $num->E164 + dialer pause + $num->extension
 
+$num->E123
+  Number in E.123 format - see https://en.wikipedia.org/wiki/E.123
+  Includes extension
+
 =head2 Configuration file
 
 If you want to set a default_country or dialer options, create a configuration file
